slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPSetInitialSpace

Specify a basis of vectors that constitute the initial space, that is, the subspace from which the solver starts to iterate.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPSetInitialSpace(NEP nep,PetscInt n,Vec is[])

Collective on nep

### Input Parameters

| nep | - the nonlinear eigensolver context
| n | - number of vectors
| is | - set of basis vectors of the initial space

### Notes

Some solvers start to iterate on a single vector (initial vector). In that case, the other vectors are ignored.

These vectors do not persist from one NEPSolve() call to the other, so the initial space should be set every time.

The vectors do not need to be mutually orthonormal, since they are explicitly orthonormalized internally.

Common usage of this function is when the user can provide a rough approximation of the wanted eigenspace. Then, convergence may be faster.

### See Also

NEPSetUp()

### Level

intermediate

### Location

src/nep/interface/nepsetup.c

### Examples

src/nep/tutorials/ex20.c.html
src/nep/tutorials/ex20f90.F90.html
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages